#[non_exhaustive]#[repr(u8)]pub enum LineSpacingType {
Percentage = 0,
Fixed = 1,
BetweenLines = 2,
}Expand description
How line spacing is calculated.
Examples
use hwpforge_foundation::LineSpacingType;
assert_eq!(LineSpacingType::default(), LineSpacingType::Percentage);Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Percentage = 0
Spacing as a percentage of the font size (default: 160%).
Fixed = 1
Fixed spacing in HwpUnit, regardless of font size.
BetweenLines = 2
Space between the bottom of one line and top of the next.